@@ -1,6 +1,6 @@
 import json
 
-from vogeler.exceptions import VogelerException
+from vogeler.exceptions import VogelerRunnerException
 from vogeler.messaging import amqp
 
 class VogelerRunner(object):
@@ -9,14 +9,17 @@ class VogelerRunner(object):
             self.routing_key = destination
             self.ch = amqp.setup_amqp(kwargs['host'], kwargs['username'], kwargs['password'])
         except:
-            raise VogelerException()
+            raise VogelerRunnerException("Unable to connect to %s as %s" % (kwargs['host'], kwargs['username']) )
 
     def message(self, message, durable=True):
         print "Vogeler(Runner) is sending a message"
-        msg = amqp.amqp.Message(json.dumps(message))
-        if durable == True:
-            msg.properties['deliver_mode'] = 2
-        self.ch.basic_publish(msg, exchange=amqp.broadcast_exchange, routing_key=self.routing_key)
+        try:
+            msg = amqp.amqp.Message(json.dumps(message))
+            if durable == True:
+                msg.properties['deliver_mode'] = 2
+            self.ch.basic_publish(msg, exchange=amqp.broadcast_exchange, routing_key=self.routing_key)
+        except:
+            raise VogelerRunnerException("Unable to publish message: %s" % message)
 
     def close(self):
         self.ch.close()
